<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="urn:Nictiz.AORTA.CareApplicationData" prefix="cad"/>
    <ns uri="urn:Nictiz.AORTA.XISApplicationData" prefix="xad"/>
    <let name="ztrFile" value="'../Zorgtoepassingsrollen/Zorgtoepassingsrollen.xml'"/>
    <let name="interactionFile" value="'../../vocab/2.16.840.1.113883.1.6.xml'"/>
    <pattern>
        <title>ContactDetails</title>
        <rule context="xad:ContactDetails">
            <assert test="xad:Telefoon or xad:Mobiel or xad:E-mail"
                >Een contactpersoon moet tenminste een (mobiele) telefoon of e-mailadres hebben</assert>
        </rule>
        
        <title>AppVersion</title>
        <rule context="xad:AppVersion">
            <let name="carrCode" value="xad:CARRCode"/>
            <let name="missingSendNames" value="for $v in document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction[cad:Sending[@required='true' and .='true']]/cad:InteractionID return (
                if (xad:Conformance[xad:InteractionID=$v]) then () else ($v))"/>
            <assert test="count($missingSendNames) = 0"
                >De volgende verplicht te verzenden interacties ontbreken: '<value-of select="$missingSendNames"/>' onder <value-of select="../xad:ApplicationName"/> 
                met profiel <value-of select="$carrCode"/></assert>
            
            <let name="missingReceiveNames" value="for $v in document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction[cad:Receiving[@required='true' and .='true']]/cad:InteractionID return (
                if (xad:Conformance[xad:InteractionID=$v]) then () else ($v))"/>
            <assert test="count($missingReceiveNames) = 0"
                >De volgende verplicht te ontvangen interacties ontbreken: '<value-of select="$missingReceiveNames"/>' onder <value-of select="../xad:ApplicationName"/> 
                met profiel <value-of select="$carrCode"/></assert>
        </rule>
        
        <title>AppVersion/CARRCode</title>
        <rule context="xad:AppVersion/xad:CARRCode">
            <let name="carrCode" value="."/>
            <assert test="document($ztrFile)/*/cad:CareApplicationRole/cad:CARName[.=$carrCode]"
                >De zorgtoepassingsrol '<value-of select="$carrCode"/>' komt niet voor in 
                '<value-of select="$ztrFile"/>'</assert>
        </rule>
        
        <title>AppVersion/Conformance/InteractionID</title>
        <rule context="xad:AppVersion/xad:Conformance/xad:InteractionID">
            <let name="carrCode" value="../../xad:CARRCode"/>
            <let name="interactionId" value="."/>
            <let name="interactionName" value="document($interactionFile)/*/hl7:code[@code=$interactionId]/@displayName"/>
            <let name="sending" value="../xad:Sending"/>
            <let name="receiving" value="../xad:Receiving"/>
            
            <assert test="document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction/cad:InteractionID[.=$interactionId]"
                >De interactie '<value-of select="$interactionId"/>' (<value-of select="$interactionName"/>) komt niet voor onder zorgtoepassingsrol '<value-of select="$carrCode"/>' in 
                '<value-of select="$ztrFile"/>'</assert>
            
            <assert test="if (document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction[cad:InteractionID[.=$interactionId]]/cad:Sending[@required='true' and .='true'] ) then (
                $sending='true' ) else ( 1=1 )"
                >De interactie '<value-of select="$interactionId"/>' (<value-of select="$interactionName"/>) is verplicht om te zenden onder zorgtoepassingsrol '<value-of select="$carrCode"/>' in 
                '<value-of select="$ztrFile"/>'</assert>
            
            <assert test="if (document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction[cad:InteractionID[.=$interactionId]]/cad:Receiving[@required='true' and .='true'] ) then (
                $receiving='true' ) else ( 1=1 )"
                >De interactie '<value-of select="$interactionId"/>' (<value-of select="$interactionName"/>) is verplicht om te accepteren onder zorgtoepassingsrol '<value-of select="$carrCode"/>' in 
                '<value-of select="$ztrFile"/>'</assert>
            
            <assert test="if (document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction[cad:InteractionID[.=$interactionId]]/cad:Sending[@required='true' and .='false'] ) then (
                $sending='false' ) else ( 1=1 )"
                >De interactie '<value-of select="$interactionId"/>' (<value-of select="$interactionName"/>) mag niet worden verzonden onder zorgtoepassingsrol '<value-of select="$carrCode"/>' in 
                '<value-of select="$ztrFile"/>'</assert>
            
            <assert test="if (document($ztrFile)/*/cad:CareApplicationRole[cad:CARName[.=$carrCode]]/cad:SupportedInteraction[cad:InteractionID[.=$interactionId]]/cad:Receiving[@required='true' and .='false'] ) then (
                $receiving='false' ) else ( 1=1 )"
                >De interactie '<value-of select="$interactionId"/>' (<value-of select="$interactionName"/>) mag niet worden geaccepteerd onder zorgtoepassingsrol '<value-of select="$carrCode"/>' in 
                '<value-of select="$ztrFile"/>'</assert>
        </rule>
        
        <!--
        <Conformance>
            <InteractionID>QUPA_IN101103</InteractionID>
            <Sending>true</Sending>
            <Receiving>false</Receiving>
        </Conformance>
        
        <SupportedInteraction>
            <InteractionID>QUPA_IN101103</InteractionID>
            <Sending required="true">true</Sending>
            <Receiving required="true">false</Receiving>
        </SupportedInteraction>
        -->
    </pattern>
</schema>
